@@ -38,7 +38,7 @@ class CalendarSupport::FreeBusyCalendarPrivate
 {
 public:
     FreeBusyCalendarPrivate()
-        : mModel(Q_NULLPTR)
+        : mModel(nullptr)
     {
 
     }
@@ -76,7 +76,7 @@ void FreeBusyCalendar::setModel(FreeBusyItemModel *model)
 {
     if (model != d->mModel) {
         if (d->mModel) {
-            disconnect(d->mModel, 0, 0, 0);
+            disconnect(d->mModel, nullptr, nullptr, nullptr);
         }
         d->mModel = model;
         connect(d->mModel, &QAbstractItemModel::layoutChanged, this, &FreeBusyCalendar::onLayoutChanged);
@@ -92,7 +92,8 @@ void FreeBusyCalendar::setModel(FreeBusyItemModel *model)
 
 void FreeBusyCalendar::deleteAllEvents()
 {
-    foreach (const KCalCore::Event::Ptr &event, d->mCalendar->events()) {
+    const KCalCore::Event::List lstEvents = d->mCalendar->events();
+    for (const KCalCore::Event::Ptr &event : lstEvents) {
         d->mCalendar->deleteEvent(event);
     }
 }
